;; Generated package description from windower.el  -*- no-byte-compile: t -*-
(define-package "windower" "0.0.1.0.20191218.215001" "Helper functions for window manipulation." '((emacs "25")) :keywords '("convenience" "tools") :authors '(("Pierre Neidhardt" . "mail@ambrevar.xyz")) :maintainer '("Pierre Neidhardt" . "mail@ambrevar.xyz") :url "https://gitlab.com/ambrevar/windower")
